@@ -12,14 +12,20 @@
 #' If no parameter is given, all parameters are retrieved.
 #' @param value_from Show results above value threshold, useful in combination with \code{parameter}.
 #' @param value_to Show results below value threshold, useful in combination with \code{parameter}.
-#' @param has_geo Filter out items that have or do not have geographic information.
+#' @param has_geo has_geo Filter out items that have or do not have geographic information.
+#' @param latitude Latitude of the center point (lat, lon) used to get measurements within a certain area.
+#' @param longitude Longitude of the center point (lat, lon) used to get measurements within a certain area.
+#' @param radius Radius (in meters) used to get measurements within a certain area, must be used with latitude and longitude
 #' @param date_from Show results after a certain date. (character year-month-day, ex. '2015-12-20')
 #' @param date_to Show results before a certain date. (character year-month-day, ex. '2015-12-20')
+#' @param attribution Logical, whether to add a column with attribution information
+#' @param averaging_period Logical, whether to add a column with averaging_period information
+#' @param source_name Logical, whether to add a column with source_name information
 #' @param limit Change the number of results returned, max is 1000.
 #' @param page The page of the results to query. This can be useful if e.g. there are 2000 measurements, then first use page=1 and page=2 with limit=100 to get all measurements for your query.
 
 #'
-#' @return a list of 3 data.frames, a results data.frame (dplyr "tbl_df") with 12 columns:
+#' @return A results data.frame (dplyr "tbl_df") with 12 columns:
 #' \itemize{
 #'  \item the name of the location ("location"),
 #'  \item the parameter ("parameter")
@@ -33,7 +39,7 @@
 #'  \item the local POSIXct time ("dateLocal"),
 #'  \item its longitude ("longitude") and latitude if available ("latitude").
 #' }
-#' meta data.frame (dplyr "tbl_df") with 1 line and 5 columns:
+#' and two attributes, a meta data.frame (dplyr "tbl_df") with 1 line and 5 columns:
 #' \itemize{
 #' \item the API name ("name"),
 #' \item the license of the data ("license"),
@@ -42,7 +48,7 @@
 #' \item the limit on the number of results ("limit"),
 #' \item the number of results found on the platform for the query ("found")
 #' }
-#' last, a timestamp data.frame (dplyr "tbl_df") with the query time and the last time at which the data was modified on the platform.
+#' and a timestamp data.frame (dplyr "tbl_df") with the query time and the last time at which the data was modified on the platform.
 
 #' @details For queries involving a city or location argument,
 #' the URL-encoded name of the city/location (as in cityURL/locationURL),
@@ -53,16 +59,23 @@
 #'   If you write city="Delhi", you do not need to write the code of the country, unless
 #'   one day there is a city with the same name in another country.
 #'
+#'   If you choose to get the attribution in the output, lines might be repeated as there might be several attributions.
+#'
 #' @examples
 #' \dontrun{
-#' aq_measurements(country='IN', limit=9, city='Chennai')
-#' aq_measurements(country='US', has_geo=TRUE)
+#' output <- aq_measurements(country='IN', limit=9, city='Chennai')
+#' output
+#' attr(output, "meta")
+#' attr(output, "timestamp")
 #' }
 #' @export
 
 aq_measurements <- function(country = NULL, city = NULL, location = NULL,# nolint
                          parameter = NULL, has_geo = NULL, date_from = NULL,
                          date_to = NULL, limit = 100, value_from = NULL,
+                         latitude = NULL, longitude = NULL, radius = NULL,
+                         attribution = FALSE, averaging_period = FALSE,
+                         source_name = FALSE,
                          value_to = NULL, page = 1) {
 
     ####################################################
@@ -79,32 +92,47 @@ aq_measurements <- function(country = NULL, city = NULL, location = NULL,# nolin
                           value_from = value_from,
                           value_to = value_to,
                           limit = limit,
+                          latitude = latitude,
+                          longitude = longitude,
+                          radius = radius,
+                          attribution = attribution,
+                          averaging_period = averaging_period,
+                          source_name = source_name,
                           page = page)
 
     ####################################################
     # GET AND TRANSFORM RESULTS
     output <- getResults(urlAQ, argsList)
-    tableOfResults <- output$results
+    tableOfResults <- output
     # if no results
     if (nrow(tableOfResults) != 0){
 
 
     tableOfResults <- addCityURL(resTable = tableOfResults)
     tableOfResults <- addLocationURL(resTable = tableOfResults)
-    names(tableOfResults)[7:8] <- c("dateUTC", "dateLocal")
+    tableOfResults <- dplyr::rename_(tableOfResults, .dots=setNames(list("date.utc"), "dateUTC"))
+    tableOfResults <- dplyr::rename_(tableOfResults, .dots=setNames(list("date.local"), "dateLocal"))
+
     tableOfResults <- tableOfResults %>% mutate_(dateUTC =
                                                    interp(~ lubridate::
                                                             ymd_hms(dateUTC)))
     tableOfResults <- tableOfResults %>% mutate_(dateLocal =
                                                    interp(~ lubridate::
                                                             ymd_hms(strptime(dateLocal, "%Y-%m-%dT%H:%M:%S"))))
-    if(ncol(tableOfResults) == 12){
-      names(tableOfResults)[9:10] <- c("latitude", "longitude")
+
+    names(tableOfResults) <- gsub("coordinates\\.", "", names(tableOfResults))
+
+    if("attribution" %in% names(tableOfResults)){
+      tableOfResults <- tidyr::unnest_(tableOfResults, "attribution", .drop = TRUE)
+      tableOfResults <- dplyr::rename_(tableOfResults, .dots=setNames(list("name"), "attribution_name"))
+      tableOfResults <- dplyr::rename_(tableOfResults, .dots=setNames(list("url"), "attribution_url"))
     }
+
     }
     ####################################################
     # DONE!
-    return(list(results = tableOfResults,
-                meta = output$meta,
-                timestamp = output$timestamp))
+    attr(tableOfResults, "meta") <- attr(output, "meta")
+    attr(tableOfResults, "timestamp") <- attr(output, "timestamp")
+
+    return(tableOfResults)
 }
